@@ -16,15 +16,15 @@ See L<Catalyst>.
 
 =head1 METHODS
 
-=head2 $self->list($c)
+=over 4
 
-Output a table of all regex actions, and their private equivalent.
+=item $self->list($c)
 
 =cut
 
 sub list {
     my ( $self, $c ) = @_;
-    my $re = Text::SimpleTable->new( [ 35, 'Regex' ], [ 36, 'Private' ] );
+    my $re = Text::SimpleTable->new( [ 36, 'Regex' ], [ 37, 'Private' ] );
     for my $regex ( @{ $self->{compiled} } ) {
         my $action = $regex->{action};
         $re->row( $regex->{path}, "/$action" );
@@ -33,10 +33,7 @@ sub list {
       if ( @{ $self->{compiled} } );
 }
 
-=head2 $self->match( $c, $path )
-
-Check path against compiled regexes, and set action to any matching
-action. Returns 1 on success and 0 on failure.
+=item $self->match( $c, $path )
 
 =cut
 
@@ -49,7 +46,6 @@ sub match {
 
     foreach my $compiled ( @{ $self->{compiled} || [] } ) {
         if ( my @snippets = ( $path =~ $compiled->{re} ) ) {
-            next unless $compiled->{action}->match($c);
             $c->req->action( $compiled->{path} );
             $c->req->match($path);
             $c->req->snippets( \@snippets );
@@ -62,33 +58,30 @@ sub match {
     return 0;
 }
 
-=head2 $self->register( $c, $action )
-
-Registers one or more regex actions for an action object.\
-Also registers them as literal paths.
-
-Returns 1 on if any regexps were registered.
+=item $self->register( $c, $action )
 
 =cut
 
 sub register {
     my ( $self, $c, $action ) = @_;
-    my $attrs    = $action->attributes;
-    my @register = @{ $attrs->{'Regex'} || [] };
+    my $attrs = $action->attributes;
+    my @register = map { @{ $_ || [] } } @{$attrs}{ 'Regex', 'Regexp' };
+    foreach
+      my $r ( map { @{ $_ || [] } } @{$attrs}{ 'LocalRegex', 'LocalRegexp' } )
+    {
+        unless ( $r =~ s/^\^// ) { $r = "(?:.*?)$r"; }
+        push( @register, '^' . $action->namespace . '/' . $r );
+    }
 
     foreach my $r (@register) {
         $self->register_path( $c, $r, $action );
         $self->register_regex( $c, $r, $action );
     }
-
     return 1 if @register;
     return 0;
 }
 
-=head2 $self->register_regex($c, $re, $action)
-
-Register an individual regex on the action. Usually called from the 
-register action.
+=item $self->register_regex($c, $re, $action)
 
 =cut
 
@@ -104,6 +97,8 @@ sub register_regex {
     );
 }
 
+=back
+
 =head1 AUTHOR
 
 Matt S Trout
