@@ -7,19 +7,20 @@ use Catalyst::Exception;
 use File::Copy ();
 use IO::File   ();
 
-__PACKAGE__->mk_accessors(qw/filename size tempname type/);
+__PACKAGE__->mk_accessors(qw/filename headers size tempname type/);
 
 sub new { shift->SUPER::new( ref( $_[0] ) ? $_[0] : {@_} ) }
 
 =head1 NAME
 
-Catalyst::Request::Upload - Catalyst Request Upload Class
+Catalyst::Request::Upload - handles file upload requests
 
 =head1 SYNOPSIS
 
-    $upload->copy_to
-    $upload->fh
+    $upload->copy_to;
+    $upload->fh;
     $upload->filename;
+    $upload->headers;
     $upload->link_to;
     $upload->size;
     $upload->slurp;
@@ -30,8 +31,7 @@ See also L<Catalyst>.
 
 =head1 DESCRIPTION
 
-This is the Catalyst Request Upload class, which provides a set of accessors 
-to the upload data.
+This class provides accessors and methods to handle client upload requests.
 
 =head1 METHODS
 
@@ -39,11 +39,12 @@ to the upload data.
 
 =item $upload->new
 
-simple constructor.
+Simple constructor.
 
 =item $upload->copy_to
 
-Copies tempname using C<File::Copy>. Returns true for success, false otherwise.
+Copies the temporary file using L<File::Copy>. Returns true for success,
+false for failure.
 
      $upload->copy_to('/path/to/target');
 
@@ -56,7 +57,7 @@ sub copy_to {
 
 =item $upload->fh
 
-Opens tempname and returns a C<IO::File> handle.
+Opens a temporary file (see tempname below) and returns an L<IO::File> handle.
 
 =cut
 
@@ -64,14 +65,13 @@ sub fh {
     my $self = shift;
 
     my $fh = IO::File->new( $self->tempname, IO::File::O_RDONLY );
-    
+
     unless ( defined $fh ) {
-        
+
         my $filename = $self->tempname;
-        
+
         Catalyst::Exception->throw(
-            message => qq/Can't open '$filename': '$!'/
-        );
+            message => qq/Can't open '$filename': '$!'/ );
     }
 
     return $fh;
@@ -79,12 +79,16 @@ sub fh {
 
 =item $upload->filename
 
-Contains client supplied filename.
+Returns the client-supplied filename.
+
+=item $upload->headers
+
+Returns an L<HTTP::Headers> object for the request.
 
 =item $upload->link_to
 
-Creates a hard link to the tempname.  Returns true for success, 
-false otherwise.
+Creates a hard link to the temporary file. Returns true for success, 
+false for failure.
 
     $upload->link_to('/path/to/target');
 
@@ -97,18 +101,18 @@ sub link_to {
 
 =item $upload->size
 
-Contains size of the file in bytes.
+Returns the size of the uploaded file in bytes.
 
 =item $upload->slurp
 
-Returns a scalar containing contents of tempname.
+Returns a scalar containing the contents of the temporary file.
 
 =cut
 
 sub slurp {
     my ( $self, $layer ) = @_;
 
-    unless ( $layer ) {
+    unless ($layer) {
         $layer = ':raw';
     }
 
@@ -126,17 +130,18 @@ sub slurp {
 
 =item $upload->tempname
 
-Contains path to the temporary spool file.
+Returns the path to the temporary file.
 
 =item $upload->type
 
-Contains client supplied Content-Type.
+Returns the client-supplied Content-Type.
 
 =back
 
-=head1 AUTHOR
+=head1 AUTHORS
 
 Sebastian Riedel, C<sri@cpan.org>
+
 Christian Hansen, C<ch@ngmedia.com>
 
 =head1 COPYRIGHT
